==> cscec5b-wzxt-impl-3.0.0-20201030.093405-4-sources.jar: com/ejianc/business/wzxt/bean/WeighEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 智能称重实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_weigh")
public class WeighEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="weigh_flag")
    private java.lang.String weighFlag; // 是否开启智能称重
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="scs_type_id")
    private java.lang.String scsTypeId; // 磅站类型主键
    @TableField(value="scs_type")
    private java.lang.String scsType; // 磅站类型说明
    @TableField(value="scs_station_code")
    private java.lang.String scsStationCode; // 站点编号
    @TableField(value="def1")
    private java.lang.String def1; // 自定义字段
    @TableField(value="def2")
    private java.lang.String def2; // 自定义字段
    @TableField(value="def3")
    private java.lang.String def3; // 自定义字段
    @TableField(value="def4")
    private java.lang.String def4; // 自定义字段
    @TableField(value="def5")
    private java.lang.String def5; // 自定义字段

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    /**
     * 是否开启智能称重
     */
    public java.lang.String getWeighFlag() {
        return weighFlag;
    }

    /**
     * 是否开启智能称重
     */
    public void setWeighFlag(java.lang.String weighFlag) {
        this.weighFlag = weighFlag;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 磅站类型主键
     */
    public java.lang.String getScsTypeId() {
        return scsTypeId;
    }

    /**
     * 磅站类型主键
     */
    public void setScsTypeId(java.lang.String scsTypeId) {
        this.scsTypeId = scsTypeId;
    }
    /**
     * 磅站类型说明
     */
    public java.lang.String getScsType() {
        return scsType;
    }

    /**
     * 磅站类型说明
     */
    public void setScsType(java.lang.String scsType) {
        this.scsType = scsType;
    }
    /**
     * 站点编号
     */
    public java.lang.String getScsStationCode() {
        return scsStationCode;
    }

    /**
     * 站点编号
     */
    public void setScsStationCode(java.lang.String scsStationCode) {
        this.scsStationCode = scsStationCode;
    }
    
}

==> cscec5b-wzxt-impl-3.0.0-20210324.075139-191-sources.jar: com/ejianc/business/wzxt/bean/WeighEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 智能称重实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_weigh")
public class WeighEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="weigh_flag")
    private java.lang.String weighFlag; // 是否开启智能称重
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="scs_type_id")
    private java.lang.String scsTypeId; // 磅站类型主键
    @TableField(value="scs_type")
    private java.lang.String scsType; // 磅站类型说明
    @TableField(value="scs_station_code")
    private java.lang.String scsStationCode; // 站点编号
    @TableField(value="weigh_type")
    private java.lang.Integer weighType; // 站点编号
    @TableField(value="def1")
    private java.lang.String def1; // 自定义字段
    @TableField(value="def2")
    private java.lang.String def2; // 自定义字段
    @TableField(value="def3")
    private java.lang.String def3; // 自定义字段
    @TableField(value="def4")
    private java.lang.String def4; // 自定义字段
    @TableField(value="def5")
    private java.lang.String def5; // 自定义字段

    public Integer getWeighType() {
        return weighType;
    }

    public void setWeighType(Integer weighType) {
        this.weighType = weighType;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    /**
     * 是否开启智能称重
     */
    public java.lang.String getWeighFlag() {
        return weighFlag;
    }

    /**
     * 是否开启智能称重
     */
    public void setWeighFlag(java.lang.String weighFlag) {
        this.weighFlag = weighFlag;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 磅站类型主键
     */
    public java.lang.String getScsTypeId() {
        return scsTypeId;
    }

    /**
     * 磅站类型主键
     */
    public void setScsTypeId(java.lang.String scsTypeId) {
        this.scsTypeId = scsTypeId;
    }
    /**
     * 磅站类型说明
     */
    public java.lang.String getScsType() {
        return scsType;
    }

    /**
     * 磅站类型说明
     */
    public void setScsType(java.lang.String scsType) {
        this.scsType = scsType;
    }
    /**
     * 站点编号
     */
    public java.lang.String getScsStationCode() {
        return scsStationCode;
    }

    /**
     * 站点编号
     */
    public void setScsStationCode(java.lang.String scsStationCode) {
        this.scsStationCode = scsStationCode;
    }
    
}
